@@ -11,12 +11,10 @@ __all__ = ['dup_filter', 'parser', 'request']
 def request(url: str):
     headers = {
         "User-Agent": (
-            "Mozilla/5.0 (X11; Linux x86_64) "
+            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) " 
             "AppleWebKit/537.36 (KHTML, like Gecko) "
-            "Chrome/106.0.0.0 Safari/537.36"
+            "Chrome/107.0.0.0 Safari/537.36"
         ),
-        "Connection": "keep-alive",
-        "Accept": "/"
     }
     req = Request(url, headers=headers)
     try:
